<?php
/*
Модуль оплаты EasyPay
 */
class Shop_Payment_System_Handler20 extends Shop_Payment_System_Handler
{
	// Идентификатор валюты в hostCMS
	private $_currency_id = 1;
	//идентификатор магазина
	private $EP_MerNo = "";
	//ключ, присваеваемый магазину системой EasyPay
	private $EP_WebKey = "";
	//тестовый режим(1- да,0 -нет)
	private $EP_Debug = 0;
	//время действительности счёта
	private $EP_Expires = 3;
	//URL успешной оплаты
	private $EP_Success_URL = '';
	//URL отмены
	private $EP_Cancel_URL = '';

	/* Вызывается на 4-ом шаге оформления заказа*/
	public function execute()
	{
		parent::execute();

		$this->printNotification();

		return $this;
	}

	protected function _processOrder()
	{
		parent::_processOrder();
		// Установка XSL-шаблонов в соответствии с настройками в узле структуры
		$this->setXSLs();
		// Отправка писем клиенту и пользователю
		$this->send();
		return $this;
	}

	// вычисление суммы товаров заказа 
	public function getSumWithCoeff()
	{
		return Shop_Controller::instance()->round(($this->_currency_id > 0
				&& $this->_shopOrder->shop_currency_id > 0
			? Shop_Controller::instance()->getCurrencyCoefficientInShopCurrency(
				$this->_shopOrder->Shop_Currency,
				Core_Entity::factory('Shop_Currency', $this->_currency_id)
			)
			: 0) * $this->_shopOrder->getAmount());
	}

	// обработка ответа от платёжной системы
	public function paymentProcessing()
	{	
		// Пришло подтверждение оплаты, обработаем его
		if (isset($_REQUEST['order_mer_code']) && 
			isset($_REQUEST['sum']) && 
			isset($_REQUEST['mer_no']) && 
			isset($_REQUEST['card']) && 
			isset($_REQUEST['purch_date']) && 
			isset($_REQUEST['notify_signature']))
		{
			$this->ProcessResult();
			return TRUE;
		}
	}

	// оплачивает заказ 
	function ProcessResult()
	{
		$oShop_Order = Core_Entity::factory('Shop_Order')->find(Core_Array::getRequest('order_mer_code', 0));

		if(is_null($oShop_Order->id) || $oShop_Order->paid) {
			// Заказ не найден
			return FALSE;
		}

		$order_mer_code = Core_Array::getPost('order_mer_code');
		$sum = Core_Array::getPost('sum');
		$mer_no = Core_Array::getPost('mer_no');
		$card = Core_Array::getPost('card');
		$purch_date = Core_Array::getPost('purch_date');
		$notify_signature = Core_Array::getPost('notify_signature');

		$hash = md5($order_mer_code . $sum . $mer_no . $card . $purch_date . $this->EP_WebKey);

		// Сравниваем хэши
		if ($hash == $notify_signature) {
			$oShop_Order->system_information = "Товар оплачен через EasyPay.\n";
			$oShop_Order->paid();
			$this->setXSLs();
			$this->send();
			header("HTTP/1.0 200 OK");
			print $status = 'OK | the notice is processed';
			die();
		} else {
			$oShop_Order->system_information = 'EasyPay хэш не совпал!';
			$oShop_Order->save();
			header("HTTP/1.0 400 Bad Request");
			print $status = 'FAILED | the notice is not processed';
			die();
		}
	}

	// печатает форму отправки запроса на сайт платёжной системы
	public function getNotification()
	{
		$sum = $this->getSumWithCoeff();

		$oShop_Currency = Core_Entity::factory('Shop_Currency')->find($this->_currency_id);

		if(!is_null($oShop_Currency->id))
		{
			?>
			<h1>Оплата через систему EasyPay</h1>
			<p>Сумма к оплате составляет <strong><?php echo $sum?> <?php echo $oShop_Currency->name?></strong></p>
			<p>Для оплаты нажмите кнопку "Оплатить".</p>
			<form name="form1" action="https://ssl.easypay.by/weborder/?EP_Module=hostcms_6" method="POST">
				<input type="hidden" name="EP_MerNo" value="<?php echo $this->EP_MerNo?>"> 
				<input type="hidden" name="EP_Sum" value="<?php echo $sum?>"> 
				<input type="hidden" name="EP_OrderNo" value="<?php echo $this->_shopOrder->id?>">
				<input type="hidden" name="EP_Expires" value="<?php echo $this->EP_Expires?>">
				<input type="hidden" name="EP_Success_URL" value="<?php echo $this->EP_Success_URL?>">
				<input type="hidden" name="EP_Cancel_URL" value="<?php echo $this->EP_Cancel_URL?>">
				<input type="hidden" name="EP_Debug" value="<?php echo $this->EP_Debug?>">
				<input type="hidden" name="EP_Encoding" value="utf-8">
				<input type="hidden" name="EP_URL_Type" value="get">
				<input type="hidden" name="EP_Comment" value="Заказ №<?php echo $this->_shopOrder->id?>"> 
				<input type="hidden" name="EP_OrderInfo" value="платёж EasyPay">
				<input type="hidden" name="EP_Hash" value="<?php echo md5($this->EP_MerNo.$this->EP_WebKey.$this->_shopOrder->id.$sum)?>">
				<input type="submit" name="submit" value="Оплатить <?php echo $sum?> <?php echo $oShop_Currency->name?>">
			</form>
			<?php
		}
	}

	public function getInvoice()
	{
		return $this->getNotification();
	}
}